@@ -1,5 +1,7 @@
 #!/bin/sh
 
+M4_MAKEFILE_AM_FILES="libloqui/protocols/jabber/Makefile.am libloqui/Makefile.am src/Makefile.am"
+
 set -e
 
 # pushd test
@@ -8,7 +10,7 @@ set -e
 
 rm -f ChangeLog
 
-if which gob2 &>/dev/null; then
+if type gob2 >/dev/null 2>&1; then
    :
 else
    echo gob2 is not installed.
@@ -17,11 +19,13 @@ fi
 
 aclocal -I m4
 
+glib-gettextize --force --copy
+
 libtoolize --force --copy
 
 autoheader
 
-for i in libloqui/Makefile.am src/Makefile.am; do
+for i in $M4_MAKEFILE_AM_FILES; do
   m4 -I. "$i.m4" > "$i"
 done
 
