@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Loqui -- IRC client for Gtk2 <http://launchpad.net/loqui/>
+ * Loqui -- IRC client for Gtk
  * Copyright (C) 2003 Yoichi Imai <sunnyone41@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -51,7 +51,7 @@ struct _AccountListDialogClass
 
 #define ACCOUNT_LIST_DIALOG_RESPONSE_CONNECT 1
 
-GtkType account_list_dialog_get_type (void) G_GNUC_CONST;
+GType account_list_dialog_get_type (void) G_GNUC_CONST;
 
 GtkWidget* account_list_dialog_new(LoquiAccountManager *manager, gboolean with_connect_button);
 
