@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Loqui -- IRC client for Gtk2 <http://launchpad.net/loqui/>
+ * Loqui -- IRC client for Gtk
  * Copyright (C) 2002-2003 Yoichi Imai <sunnyone41@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -46,7 +46,7 @@ static GtkTreeViewClass *parent_class = NULL;
 static void channel_tree_class_init(ChannelTreeClass *klass);
 static void channel_tree_init(ChannelTree *channel_tree);
 static void channel_tree_finalize(GObject *object);
-static void channel_tree_destroy(GtkObject *object);
+static void channel_tree_destroy(GtkWidget *object);
 
 static void channel_tree_row_activated_cb(ChannelTree *tree, GtkTreePath *path, GtkTreeViewColumn *col, gpointer data);
 static void channel_tree_row_selected_cb(GtkTreeSelection *selection, gpointer data);
@@ -90,13 +90,12 @@ static void
 channel_tree_class_init(ChannelTreeClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS(klass);
-        GtkObjectClass *gtk_object_class = GTK_OBJECT_CLASS(klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);
 
         parent_class = g_type_class_peek_parent(klass);
         
         object_class->finalize = channel_tree_finalize;
-        gtk_object_class->destroy = channel_tree_destroy;
+        widget_class->destroy = channel_tree_destroy;
 
 	widget_class->key_press_event = channel_tree_key_press_event;
 }
@@ -125,7 +124,7 @@ channel_tree_finalize(GObject *object)
 	g_free(channel_tree->priv);
 }
 static void 
-channel_tree_destroy(GtkObject *object)
+channel_tree_destroy(GtkWidget *object)
 {
         ChannelTree *channel_tree;
 
@@ -134,8 +133,8 @@ channel_tree_destroy(GtkObject *object)
 
         channel_tree = CHANNEL_TREE(object);
 
-        if (GTK_OBJECT_CLASS(parent_class)->destroy)
-                (* GTK_OBJECT_CLASS(parent_class)->destroy) (object);
+        if (GTK_WIDGET_CLASS(parent_class)->destroy)
+                (* GTK_WIDGET_CLASS(parent_class)->destroy) (object);
 }
 static void /* double click */
 channel_tree_row_activated_cb(ChannelTree *tree, GtkTreePath *path, GtkTreeViewColumn *col, gpointer data)
