@@ -12,9 +12,9 @@
 #define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_SAVE_LOG FALSE
 #define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_SELECT_CHANNEL_JOINED TRUE
 #define LOQUI_GENERAL_PREF_GTK_DEFAULT_GENERAL_TIME_FORMAT "%H:%M "
-#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_CHANNEL_TREE_HEIGHT 180
-#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_CHANNEL_TREE_WIDTH 100
-#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_COMMON_BUFFER_HEIGHT 150
+#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_HPANED_POSITION 360
+#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_VPANED_LEFT_POSITION 200
+#define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_VPANED_RIGHT_POSITION 200
 #define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_SAVE_SIZE TRUE
 #define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_WINDOW_HEIGHT 400
 #define LOQUI_GENERAL_PREF_GTK_DEFAULT_SIZE_WINDOW_WIDTH 480
