@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Loqui -- IRC client for Gtk2 <http://launchpad.net/loqui/>
+ * Loqui -- IRC client for Gtk
  * Copyright (C) 2002-2003 Yoichi Imai <sunnyone41@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -58,7 +58,7 @@ struct _LoquiChannelBufferGtkClass
 };
 
 
-GtkType loqui_channel_buffer_gtk_get_type(void) G_GNUC_CONST;
+GType loqui_channel_buffer_gtk_get_type(void) G_GNUC_CONST;
 
 LoquiChannelBufferGtk* loqui_channel_buffer_gtk_new(LoquiPrefPartial *ppref_channel_buffer);
 
