@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Loqui -- Chat client for Gtk2 <http://launchpad.net/loqui/>
+ * Loqui -- Chat client for Gtk
  * Copyright (C) 2004 Yoichi Imai <sunnyone41@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -47,7 +47,7 @@ static void loqui_dropdown_box_dispose(GObject *object);
 static void loqui_dropdown_box_get_property(GObject *object, guint param_id, GValue *value, GParamSpec *pspec);
 static void loqui_dropdown_box_set_property(GObject *object, guint param_id, const GValue *value, GParamSpec *pspec);
 
-static void loqui_dropdown_box_destroy(GtkObject *object);
+static void loqui_dropdown_box_destroy(GtkWidget *object);
 
 static void loqui_dropdown_box_menu_deactivated_cb(GtkWidget *widget, LoquiDropdownBox *dropdown_box);
 static void loqui_dropdown_box_detacher(GtkWidget *widget, GtkMenu *menu);
@@ -144,7 +144,7 @@ loqui_dropdown_box_class_init(LoquiDropdownBoxClass *klass)
         object_class->dispose = loqui_dropdown_box_dispose;
         object_class->get_property = loqui_dropdown_box_get_property;
         object_class->set_property = loqui_dropdown_box_set_property;
-	GTK_OBJECT_CLASS(klass)->destroy = loqui_dropdown_box_destroy;
+	GTK_WIDGET_CLASS(klass)->destroy = loqui_dropdown_box_destroy;
 }
 static void 
 loqui_dropdown_box_init(LoquiDropdownBox *dbox)
@@ -156,7 +156,7 @@ loqui_dropdown_box_init(LoquiDropdownBox *dbox)
 	dbox->priv = priv;
 }
 static void 
-loqui_dropdown_box_destroy(GtkObject *object)
+loqui_dropdown_box_destroy(GtkWidget *object)
 {
         LoquiDropdownBox *dbox;
 
@@ -165,8 +165,8 @@ loqui_dropdown_box_destroy(GtkObject *object)
 
         dbox = LOQUI_DROPDOWN_BOX(object);
 
-        if (GTK_OBJECT_CLASS(parent_class)->destroy)
-                (* GTK_OBJECT_CLASS(parent_class)->destroy)(object);
+        if (GTK_WIDGET_CLASS(parent_class)->destroy)
+                (* GTK_WIDGET_CLASS(parent_class)->destroy)(object);
 }
 static gboolean
 loqui_dropdown_box_button_press_event(GtkWidget *widget, GdkEventButton *event, gpointer data)
