@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Loqui -- Chat client for Gtk2 <http://launchpad.net/loqui/>
+ * Loqui -- Chat client for Gtk
  * Copyright (C) 2004 Yoichi Imai <sunnyone41@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -72,7 +72,7 @@ static void loqui_select_dialog_dispose(GObject *object);
 static void loqui_select_dialog_get_property(GObject *object, guint param_id, GValue *value, GParamSpec *pspec);
 static void loqui_select_dialog_set_property(GObject *object, guint param_id, const GValue *value, GParamSpec *pspec);
 
-static void loqui_select_dialog_destroy(GtkObject *object);
+static void loqui_select_dialog_destroy(GtkWidget *object);
 GType
 loqui_select_dialog_get_type(void)
 {
@@ -176,7 +176,7 @@ loqui_select_dialog_class_init(LoquiSelectDialogClass *klass)
         object_class->dispose = loqui_select_dialog_dispose;
         object_class->get_property = loqui_select_dialog_get_property;
         object_class->set_property = loqui_select_dialog_set_property;
-        GTK_OBJECT_CLASS(klass)->destroy = loqui_select_dialog_destroy;
+        GTK_WIDGET_CLASS(klass)->destroy = loqui_select_dialog_destroy;
 }
 static void 
 loqui_select_dialog_init(LoquiSelectDialog *sdialog)
@@ -188,7 +188,7 @@ loqui_select_dialog_init(LoquiSelectDialog *sdialog)
 	sdialog->priv = priv;
 }
 static void 
-loqui_select_dialog_destroy(GtkObject *object)
+loqui_select_dialog_destroy(GtkWidget *object)
 {
         LoquiSelectDialog *sdialog;
 
@@ -197,8 +197,8 @@ loqui_select_dialog_destroy(GtkObject *object)
 
         sdialog = LOQUI_SELECT_DIALOG(object);
 
-        if (GTK_OBJECT_CLASS(parent_class)->destroy)
-                (* GTK_OBJECT_CLASS(parent_class)->destroy)(object);
+        if (GTK_WIDGET_CLASS(parent_class)->destroy)
+                (* GTK_WIDGET_CLASS(parent_class)->destroy)(object);
 }
 GtkWidget *
 loqui_select_dialog_new(LoquiApp *app)
@@ -233,7 +233,7 @@ loqui_select_dialog_new(LoquiApp *app)
 			       GTK_STOCK_OK, GTK_RESPONSE_OK,
 			       NULL);
 
-	dialog_vbox = GTK_DIALOG(sdialog)->vbox;
+	dialog_vbox = gtk_dialog_get_content_area(GTK_DIALOG(sdialog));
 
 	hbox1 = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(dialog_vbox), hbox1, FALSE, FALSE, 5);
